@@ -1,10 +1,18 @@
 from django.conf import settings
 
-MERCHANT_ID = settings.PAYFAST_MERCHANT_ID
-MERCHANT_KEY = settings.PAYFAST_MERCHANT_KEY
-
 TEST_MODE = getattr(settings, 'PAYFAST_TEST_MODE', False)
 
+TEST_MERCHANT_ID = '10000100'
+TEST_MERCHANT_KEY = '46f0cd694581a'
+
+MERCHANT_ID = getattr(settings, 'PAYFAST_MERCHANT_ID', TEST_MERCHANT_ID)
+MERCHANT_KEY = getattr(settings, 'PAYFAST_MERCHANT_KEY', TEST_MERCHANT_KEY)
+
+if TEST_MODE:
+    # real id and key don't work in sandbox
+    MERCHANT_ID = TEST_MERCHANT_ID
+    MERCHANT_KEY = TEST_MERCHANT_KEY
+
 LIVE_SERVER = 'https://www.payfast.co.za'
 SANDBOX_SERVER = 'https://sandbox.payfast.co.za'
 SERVER = SANDBOX_SERVER if TEST_MODE else LIVE_SERVER
